@@ -1,5 +1,4 @@
 import csv
-from hashlib import new
 import json
 import logging
 
@@ -42,8 +41,8 @@ def make_csv_from_json(file, data, delimiter=None, keys=None):
     if not delimiter:
         delimiter = "|"
 
-    with open(file, "w") as f:
-        w = csv.DictWriter(f, fieldnames=keys, delimiter=delimiter, newline="")
+    with open(file, "w", newline="") as f:
+        w = csv.DictWriter(f, fieldnames=keys, delimiter=delimiter)
         w.writeheader()
         w.writerows(data)
 
